/*
 * The MIT License
 *
 * Copyright 2022 Ivan Smitka <ivan at stimulus dot cz>.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR
 * ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH
 * THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 *
 * Document : _.js Created on : 24 Feb 2022 Author : Ivan Smitka <ivan at stimulus dot cz>
 */

var eb;
WP_EventBanner = {
    init: function() {
        eb = this;
        this.widget = jQuery(".EventBanner");
        if (this.widget.length > 0) {
            this.collapsible = parseInt(this.widget.data("collapsible"));
            this.collapsed = parseInt(this.widget.data("collapsed"));
            var countdownElement = jQuery("[data-countdown]", this.widget);
            if (countdownElement.length > 0) {
                var d = parseInt(countdownElement.data("countdown"));
                countdownElement.data("x", setInterval(function() { eb.countdown(countdownElement, d * 1000); }, 1000));
            }
            jQuery(".collapsed", this.widget).click(function(event) {
                event.preventDefault();
                event.stopPropagation();
                if(eb.widget.hasClass("small") && eb.widget.data("link")) {
                    window.open(eb.widget.data("link"), "_blank");
                } else {
                    eb.widget.removeClass("collapsed");
                }
            });
            jQuery(".collapse", this.widget).click(function(event) {
                event.preventDefault();
                event.stopPropagation();
                eb.widget.addClass("collapsed");
            });
            jQuery(window).resize(eb.onResize);
            eb.onResize();
        }
    },
    countdown: function(el, d) {
        // Get today's date and time
        var now = new Date;

        // Find the distance between now and the count down date
        var distance = d - now.getTime() + (now.getTimezoneOffset() * 60 * 1000);

        // If the count down is finished, write some text
        if (distance < 0) {
            clearInterval(el.data("x"));
            el.html("");
        } else {
            // Time calculations for days, hours, minutes and seconds
            jQuery(".days", el).html(Math.floor(distance / (1000 * 60 * 60 * 24)));
            jQuery(".hours", el).html(Math.floor((distance % (1000 * 60 * 60 * 24)) / (1000 * 60 * 60)));
            jQuery(".minutes", el).html(Math.floor((distance % (1000 * 60 * 60)) / (1000 * 60)));
            jQuery(".seconds", el).html(Math.floor((distance % (1000 * 60)) / 1000));
        }
    },
    onResize: function() {
        var width = jQuery(window).innerWidth();
        if (width < eb.collapsible) {
            eb.widget.addClass("collapsible");
            eb.widget.addClass("collapsed");
            if(width < eb.collapsed) {
                eb.widget.addClass("small");
            } else {
                eb.widget.removeClass("small");
            }
        } else {
            eb.widget.removeClass("collapsible");
            eb.widget.removeClass("collapsed");
        }
        eb.widget.css("display", "block");
    }
}

jQuery(document).ready(function() {
    WP_EventBanner.init();
});